# (un)define the next line to either build for the newest or all current kernels
#define buildforkernels newest
#define buildforkernels current
%define buildforkernels akmod

%define repo rpmfusion

# Define the kmod package name here.
%define kmod_name pexml

%{!?RPM_GIT_VERSION:%define RPM_GIT_VERSION unknown}

# If kversion isn't defined on the rpmbuild line, define it here.
%{!?kversion: %define kversion %(rpm -q kernel-devel|sed -e 's/^[a-z-]*//'|sort -n|tail -n 1|sed -e 's/\(PAE\|xenU\|xen\|smp\|hugemem\)//g')}

Name:    %{kmod_name}-kmod
Version: 1.37.3
Release: %{RPM_GIT_VERSION}%{?dist}
Group:   System Environment/Kernel
License: GPL
Summary: M-Link kernel modules
URL:     http://afi.jinr.ru/mlink


BuildRequires: %{_bindir}/kmodtool
ExclusiveArch: i686 x86_64

# get the proper build-sysbuild package from the repo, which
# tracks in all the kernel-devel packages
%{!?kernels:BuildRequires: buildsys-build-rpmfusion-kerneldevpkgs-%{?buildforkernels:%{buildforkernels}}%{!?buildforkernels:current}-%{_target_cpu} }


# Sources
Source0:  mlink-%{version}.tar.gz


# kmodtool does its magic here
%{expand:%(kmodtool --target %{_target_cpu} --repo rpmfusion --kmodname %{name} %{?buildforkernels:--%{buildforkernels}} %{?kernels:--for-kernels "%{?kernels}"} 2>/dev/null) }


# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
M-Link is a custom communication interface based on packet structure like
Ethernet. It is used with ADCM, VMEDAQ projects.

%prep
%setup -q -T -c -a 0
# error out if there was something wrong with kmodtool
%{?kmodtool_check}

# print kmodtool output for debugging purposes:
kmodtool --target %{_target_cpu}  --repo rpmfusion --kmodname %{name} %{?buildforkernels:--%{buildforkernels}} %{?kernels:--for-kernels "%{?kernels}"} 2>/dev/null



# apply patches and do other stuff here
# pushd foo-%{version}
# #patch0 -p1 -b .suffix
# popd

for kernel_version in %{?kernel_versions} ; do
    cp -al mlink-%{version} _kmod_build_${kernel_version%%___*}
done


%build
# set build environment
export NODEBUG=yes
export svn_rev=%{svn_rev}

for kernel_version in %{?kernel_versions}; do
    pushd  _kmod_build_${kernel_version%%___*}/driver
#    make %{?_smp_mflags} -C "${kernel_version##*___}" \
#    SUBDIRS="${PWD}/_kmod_build_${kernel_version%%___*}" modules \
#    M=$PWD/driver
#    popd
    make %{?_smp_mflags} \
        svn_rev=%{svn_rev} \
        BUILD_DIR=${kernel_version##*___} \
        KDIR=${kernel_version##*___} \
        KVERS=${kernel_version%%___*}
    popd
done


%install
rm -rf ${RPM_BUILD_ROOT}

for kernel_version in %{?kernel_versions} ; do
    install -p -D -m 0755 _kmod_build_${kernel_version%%___*}/driver/%{kmod_name}.ko  ${RPM_BUILD_ROOT}%{kmodinstdir_prefix}/${kernel_version%%___*}/%{kmodinstdir_postfix}/%{kmod_name}.ko
done
%{?akmod_install}


%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Wed Oct 16 2019  <Ilja.Slepnev@jinr.ru> - 1.37.2
- include git hash in rpm release string

* Thu Oct  3 2019  <Ilja.Slepnev@jinr.ru> - 1.37
- Linux 5.x compatibility
- added ioctls ML_IOC_READ_BOARD_INFO, ML_IOC_GET_SERIAL_ID

* Thu Apr 19 2018  <Ilja.Slepnev@jinr.ru> - 1.35
- Flash programmer interface

* Wed Feb  7 2018  <Ilja.Slepnev@jinr.ru> - 1.34
- GTX, SFP control/status

* Tue Jul 28 2015  <Ilja.Slepnev@jinr.ru> - 1.33.3
- rpm provides mlink-kmod-common, pexml-kmod-common

* Fri Sep 27 2013  <Ilja.Slepnev@jinr.ru> - 1.33
- correct status report with firmware r.15176

* Thu Nov 29 2012  <Ilja.Slepnev@jinr.ru> - 
- EL6 compatible spec file

* Wed May 13 2009  <Ilja.Slepnev@jinr.ru> - 
- Fixed package name

* Tue May 12 2009  <Ilja.Slepnev@jinr.ru> - 
- Split in two packages: mlink and mlink-kmod

* Wed Apr 22 2009  <Ilja.Slepnev@jinr.ru> - 
- 1.30: build with kmodtool2. Package name changed: mlink-utils, mlink-kmod

* Mon Apr 20 2009  <Ilja.Slepnev@jinr.ru> - 
- removed mlink.ko file. use melink.ko

* Wed Apr 08 2009  <Ilja.Slepnev@jinr.ru> - 
- 1.29: Removed special run-mode. Packet mode only.

* Wed Mar 25 2009  <Ilja.Slepnev@jinr.ru> - 
- Fixed communication problem caused by receiver_reset() in RXC handler
- testlink: Fixed clock locking problem when changing loopback mode

* Tue Mar  3 2009  <Ilja.Slepnev@jinr.ru> - 
- Changed version to 1.28
- Added MlinkDevice interface class

* Thu Feb 12 2009  <Ilja.Slepnev@jinr.ru> - 
- Added control frame loopback bit

* Thu Dec 11 2008  <Ilja.Slepnev@jinr.ru> - 
- Handle link up/down status on reset, use OSD bit

* Fri Nov 28 2008  <Ilja.Slepnev@jinr.ru> - 
- defined 'kdir' macro
- fixed x86_64 warnings

* Thu Nov 27 2008  <Ilja.Slepnev@jinr.ru> - 
- spec file corrected to build on Fedora 10.

* Tue Nov 18 2008  <Ilja.Slepnev@jinr.ru> - 
- Initial build.

